@@ -35,22 +35,24 @@ graph_adhesion <- function() {
 graph_assortativity <- function(attr, in_attr = NULL, directed = TRUE) {
   graph <- .G()
   attr <- enquo(attr)
-  attr <- eval_tidy(attr, .N())
+  attr <- eval_tidy(attr, .N(focused = FALSE))
   if (is.numeric(attr)) {
     in_attr <- enquo(in_attr)
-    in_attr <- eval_tidy(in_attr, .N())
+    in_attr <- eval_tidy(in_attr, .N(focused = FALSE))
     assortativity(graph, attr, in_attr, directed)
   } else {
     assortativity_nominal(graph, as.factor(attr), directed)
   }
 }
-#' @describeIn graph_measures Calculate the number of automorphisms of the graph. Wraps [igraph::automorphisms()]
-#' @inheritParams igraph::automorphisms
-#' @importFrom igraph automorphisms
+#' @describeIn graph_measures Calculate the number of automorphisms of the graph. Wraps [igraph::count_automorphisms()]
+#' @inheritParams igraph::count_automorphisms
+#' @importFrom igraph count_automorphisms
 #' @export
-graph_automorphisms <- function(sh = 'fm') {
+graph_automorphisms <- function(sh = 'fm', colors = NULL) {
   graph <- .G()
-  as.numeric(automorphisms(graph, sh = sh)$group_size)
+  colors <- enquo(colors)
+  colors <- eval_tidy(colors, .N(focused = FALSE))
+  as.numeric(count_automorphisms(graph, colors = colors, sh = sh)$group_size)
 }
 #' @describeIn graph_measures Get the size of the largest clique. Wraps [igraph::clique_num()]
 #' @importFrom igraph clique_num
@@ -67,7 +69,7 @@ graph_clique_num <- function() {
 graph_clique_count <- function(min = NULL, max = NULL, subset = NULL) {
   graph <- .G()
   subset <- enquo(subset)
-  subset <- eval_tidy(subset, .N())
+  subset <- eval_tidy(subset, .N(focused = FALSE))
   if (is.logical(subset)) subset <- which(subset)
   count_max_cliques(graph, min, max, subset)
 }
@@ -94,10 +96,7 @@ graph_motif_count <- function(size = 3, cut.prob = rep(0, size)) {
 graph_diameter <- function(weights = NULL, directed = TRUE, unconnected = TRUE) {
   graph <- .G()
   weights <- enquo(weights)
-  weights <- eval_tidy(weights, .E())
-  if (is.null(weights)) {
-    weights <- NA
-  }
+  weights <- eval_tidy(weights, .E(focused = FALSE)) %||% NA
   diameter(graph, directed, unconnected, weights)
 }
 #' @describeIn graph_measures Measrues the length of the shortest circle in the graph. Wraps [igraph::girth()]
@@ -166,15 +165,17 @@ graph_reciprocity <- function(ignore_loops = TRUE, ratio = FALSE) {
 graph_min_cut <- function(capacity = NULL) {
   graph <- .G()
   capacity <- enquo(capacity)
-  capacity <- eval_tidy(capacity, .E())
+  capacity <- eval_tidy(capacity, .E(focused = FALSE))
   min_cut(graph, capacity = capacity)
 }
 #' @describeIn graph_measures Calculates the mean distance between all node pairs in the graph. Wraps [igraph::mean_distance()]
 #' @importFrom igraph mean_distance
 #' @export
-graph_mean_dist <- function(directed = TRUE, unconnected = TRUE) {
+graph_mean_dist <- function(directed = TRUE, unconnected = TRUE, weights = NULL) {
   graph <- .G()
-  mean_distance(graph, directed = directed, unconnected = unconnected)
+  weights <- enquo(weights)
+  weights <- eval_tidy(weights, .E(focused = FALSE)) %||% NA
+  mean_distance(graph, directed = directed, unconnected = unconnected, weights = weights)
 }
 #' @describeIn graph_measures Calculates the modularity of the graph contingent on a provided node grouping
 #' @param group The node grouping to calculate the modularity on
@@ -184,7 +185,17 @@ graph_modularity <- function(group, weights = NULL) {
   graph <- .G()
   group <- enquo(group)
   weights <- enquo(weights)
-  group <- eval_tidy(group, .N())
-  weights <- eval_tidy(weights, .E())
+  group <- eval_tidy(group, .N(focused = FALSE))
+  weights <- eval_tidy(weights, .E(focused = FALSE))
   modularity(graph, group, weights)
 }
+#' @describeIn graph_measures Calculate the global efficiency of the graph
+#' @importFrom igraph global_efficiency
+#' @importFrom rlang enquo eval_tidy
+#' @export
+graph_efficiency <- function(weights = NULL, directed = TRUE) {
+  graph <- .G()
+  weights <- enquo(weights)
+  weights <- eval_tidy(weights, .E(focused = FALSE)) %||% NA
+  global_efficiency(graph, weights = weights, directed = directed)
+}
