@@ -2,7 +2,7 @@
 #'
 #' The `morph`/`unmorph` verbs are used to create temporary representations of
 #' the graph, such as e.g. its search tree or a subgraph. A morphed graph will
-#' accept any of the standard `dplyr` verbs, and changed to the data is
+#' accept any of the standard `dplyr` verbs, and changes to the data is
 #' automatically propagated to the original graph when unmorphing. Tidygraph
 #' comes with a range of [morphers], but is it also possible to supply your own.
 #' See Details for the requirement for custom morphers. The `crystallise` verb
@@ -38,7 +38,7 @@
 #' `.tidygraph_edge_index` column (or both). Note that it is possible for the
 #' morph to have the edges mapped back to the original nodes and vice versa
 #' (e.g. as with [to_linegraph]). In that case the edge data in the morphed
-#' graph(s) will contain a `.tidygraph_node_index` column and or the node data a
+#' graph(s) will contain a `.tidygraph_node_index` column and/or the node data a
 #' `.tidygraph_edge_index` column. If the morphing results in the collapse of
 #' multiple columns or edges the index columns should be converted to list
 #' columns mapping the new node/edge back to all the nodes/edges it represents.
@@ -91,8 +91,12 @@ convert <- function(.data, .f, ..., .select = 1, .clean = FALSE) {
 #' @export
 #' @importFrom rlang as_quosure sym quo_text enquo
 morph.tbl_graph <- function(.data, .f, ...) {
+  if (is.focused_tbl_graph(.data)) {
+    cli::cli_inform('Unfocusing prior to morphing')
+    .data <- unfocus(.data)
+  }
   if (inherits(.data, 'grouped_tbl_graph')) {
-    message('Ungrouping prior to morphing')
+    cli::cli_inform('Ungrouping prior to morphing')
     .data <- ungroup(.data)
   }
   .register_graph_context(.data)
@@ -114,7 +118,7 @@ morph.tbl_graph <- function(.data, .f, ...) {
 }
 #' @export
 morph.morphed_tbl_graph <- function(.data, .f, ...) {
-  message('Unmorphing tbl_graph first...')
+  cli::cli_inform('Unmorphing {.arg .data} first...')
   .data <- unmorph(.data)
   morph(.data, .f, ...)
 }
@@ -158,13 +162,13 @@ crystallise.morphed_tbl_graph <- function(.data) {
 }
 #' @export
 convert.tbl_graph <- function(.data, .f, ..., .select = 1, .clean = FALSE) {
-  stopifnot(length(.select) == 1)
+  if (length(.select) != 1) cli::cli_abort("{.arg .select} must be a single scalar")
   graphs <- crystallise(morph(.data, .f, ...))
   if (is.character(.select)) {
     .select <- which(.select == graphs$name)[1]
-    if (is.na(.select)) stop('.select does not match any named graph', call. = FALSE)
+    if (is.na(.select)) cli::cli_abort('{.arg .select} does not match any named graph')
   }
-  if (.select > nrow(graphs)) stop('convert did not create ', .select, ' graphs', call. = FALSE)
+  if (.select > nrow(graphs)) cli::cli_abort(c('{.fn convert} did not create {.select} number of graphs', 'i' = 'Set a lower {.arg .select}'))
   graph <- graphs$graph[[.select]]
   if (.clean) {
     nodes <- as_tibble(graph, active = 'nodes')
@@ -182,12 +186,12 @@ convert.tbl_graph <- function(.data, .f, ..., .select = 1, .clean = FALSE) {
 #' @importFrom igraph vertex_attr_names edge_attr_names
 check_morph <- function(morph) {
   if (!all(vapply(morph, inherits, logical(1), 'tbl_graph'))) {
-    stop('morph must consist of tbl_graphs')
+    cli::cli_abort('{.arg morph} must consist of {.cls tbl_graphs}')
   }
   lapply(morph, function(m) {
     attr_names <- c(vertex_attr_names(m), edge_attr_names(m))
     if (!any(c('.tidygraph_node_index', '.tidygraph_edge_index') %in% attr_names)) {
-      stop('Morph must contain reference to at either nodes or edges', call. = FALSE)
+      cli::cli_abort('{.arg morph} must contain reference to either nodes or edges')
     }
   })
   NULL
