@@ -3,11 +3,10 @@
 #' @importFrom igraph delete_vertices delete_edges
 #' @importFrom rlang enquo
 sample_frac.tbl_graph <- function(tbl, size = 1, replace = FALSE, weight = NULL, .env = parent.frame(), ...) {
+  tbl <- unfocus(tbl)
   d_tmp <- as_tibble(tbl)
   weight <- enquo(weight)
-  if ('.tbl_graph_index' %in% names(d_tmp)) {
-    stop('The attribute name ".tbl_graph_index" is reserved', call. = FALSE)
-  }
+  check_reserved(d_tmp)
   orig_ind <- seq_len(nrow(d_tmp))
   d_tmp$.tbl_graph_index <- orig_ind
   d_tmp <- sample_frac(d_tmp, size = size, replace = replace, weight = !! weight, .env = .env)
