@@ -1,5 +1,3 @@
-context("activate")
-
 test_that("active<- and activate works for tbl_graph", {
   gr1 <- create_notable('bull')
   gr1 <- activate(gr1, edges)
@@ -27,3 +25,5 @@ test_that('activate activates all morphed graphs', {
   gr1 <- activate(gr1, 'edges')
   expect_true(all(sapply(gr1, active) == 'edges'))
 })
+
+test_empty_context()
