@@ -1,5 +1,3 @@
-context("distinct")
-
 test_that("distinct works", {
   gr <- create_notable('bull') %>%
     mutate(id = c(1,1,1,2,2)) %>%
@@ -10,3 +8,5 @@ test_that("distinct works", {
   gr2 <- gr %>% activate(edges) %>% distinct(id)
   expect_equal(igraph::gsize(gr2), 3)
 })
+
+test_empty_context()
