@@ -1,5 +1,3 @@
-context("filter")
-
 test_that("filter works", {
   id_nodes <- create_notable('bull') %>%
     mutate(id = seq_len(n())) %>%
@@ -13,3 +11,5 @@ test_that("filter works", {
     pull(id)
   expect_equal(id_edges, 1:3)
 })
+
+test_empty_context()
